# rosinenpicker

![Python Packaging](https://github.com/joheli/rosinenpicker/workflows/Packaging/badge.svg)

'Rosinenpicker' is German for 'cherry picker'. Which explains what this program does:
  - It goes through a list of documents to extract just those juicy bits you are interested in. 
  - How does it locate the interesting text passages, you ask? Through regex patterns. 
But please do read on.

# Installation

Folks this is coming soon so hang on to your pants!